==> org.simantics.charts.source_0.0.1.v20201025-164704.jar: org/simantics/charts/ui/CSVExportPlan.java <==
/*******************************************************************************
 * Copyright (c) 2012 Association for Decentralized Information Management in
 * Industry THTH ry.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     VTT Technical Research Centre of Finland - initial API and implementation
 *******************************************************************************/
package org.simantics.charts.ui;

import java.io.File;
import java.util.ArrayDeque;
import java.util.Collection;
import java.util.Deque;
import java.util.HashSet;
import java.util.List;

import org.simantics.Simantics;
import org.simantics.db.Resource;
import org.simantics.db.management.ISessionContext;
import org.simantics.history.csv.ColumnSeparator;
import org.simantics.history.csv.DecimalSeparator;
import org.simantics.history.csv.ExportInterpolation;
import org.simantics.project.IProject;

/**
 * @author Antti Villberg
 */
public class CSVExportPlan {
	
    // Input
    ISessionContext sessionContext;
    IProject        project;
    Object          selection;
    Deque<String>   recentLocations;

    // Output
    Collection<Resource> items = new HashSet<>();
    File                 exportLocation;

    
    public double				startTime;
    public double				timeStep;
    public DecimalSeparator	decimalSeparator;
    public ColumnSeparator		columnSeparator;
    public boolean             resample;
    public ExportInterpolation samplingMode;
    public int					timeDigits;
    public int					floatDigits;
    public int					doubleDigits;


    /**
     * <code>true</code> if the model should be overwritten without a warning.
     */
    boolean         overwrite;

    /**
     * Constructor for SCL support
     */
    public CSVExportPlan(double startTime, double timeStep, DecimalSeparator dsep, ColumnSeparator csep, boolean resample, ExportInterpolation mode, int timeDigits, int floatDigits, int doubleDigits) {
        this.sessionContext = Simantics.getSessionContext();
        this.recentLocations = new ArrayDeque<>();
        
        this.startTime = startTime;
        this.timeStep = timeStep;
        this.decimalSeparator = dsep;
        this.columnSeparator = csep;
        this.resample = resample;
        this.samplingMode = mode;
        this.timeDigits = timeDigits;
        this.floatDigits = floatDigits;
        this.doubleDigits = doubleDigits;
    }

    public void setItems(List<Resource> items) {
        this.items = items;
    }

    CSVExportPlan(ISessionContext sessionContext, Deque<String> recentLocations) {
        this.sessionContext = sessionContext;
        this.recentLocations = recentLocations;
    }

}

==> org.simantics.charts.source_0.0.2.v20251010-091622.jar: org/simantics/charts/ui/CSVExportPlan.java <==
/*******************************************************************************
 * Copyright (c) 2012 Association for Decentralized Information Management in
 * Industry THTH ry.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     VTT Technical Research Centre of Finland - initial API and implementation
 *******************************************************************************/
package org.simantics.charts.ui;

import java.io.File;
import java.nio.charset.Charset;
import java.util.ArrayDeque;
import java.util.Collection;
import java.util.Deque;
import java.util.HashSet;
import java.util.List;

import org.simantics.Simantics;
import org.simantics.db.Resource;
import org.simantics.db.management.ISessionContext;
import org.simantics.history.csv.ColumnSeparator;
import org.simantics.history.csv.DecimalSeparator;
import org.simantics.history.csv.ExportInterpolation;
import org.simantics.project.IProject;

/**
 * @author Antti Villberg
 */
public class CSVExportPlan {
	
    // Input
    ISessionContext sessionContext;
    IProject        project;
    Object          selection;
    Deque<String>   recentLocations;

    // Output
    Collection<Resource> items = new HashSet<>();
    File                 exportLocation;

    
    public double				startTime;
    public double				timeStep;
    public DecimalSeparator	decimalSeparator;
    public ColumnSeparator		columnSeparator;
    public boolean             resample;
    public ExportInterpolation samplingMode;
    public int					timeDigits;
    public int					floatDigits;
    public int					doubleDigits;

    /**
     * Configures the encoding (charset) to use for writing the output CSV file.
     */
    public String encoding;

    /**
     * <code>true</code> if the model should be overwritten without a warning.
     */
    boolean         overwrite;

    /**
     * Constructor for SCL support.
     * 
     * Don't change the parametrization. Changing it will break the existing SCL API.
     */
    public CSVExportPlan(double startTime, double timeStep, DecimalSeparator dsep, ColumnSeparator csep, boolean resample, ExportInterpolation mode, int timeDigits, int floatDigits, int doubleDigits) {
        this.sessionContext = Simantics.getSessionContext();
        this.recentLocations = new ArrayDeque<>();
        
        this.startTime = startTime;
        this.timeStep = timeStep;
        this.decimalSeparator = dsep;
        this.columnSeparator = csep;
        this.resample = resample;
        this.samplingMode = mode;
        this.timeDigits = timeDigits;
        this.floatDigits = floatDigits;
        this.doubleDigits = doubleDigits;

        // By default use system default encoding for output
        this.encoding = Charset.defaultCharset().name();
    }

    public CSVExportPlan setItems(List<Resource> items) {
        this.items = items;
        return this;
    }

    public CSVExportPlan setEncoding(String encoding) {
        this.encoding = encoding;
        return this;
    }

    CSVExportPlan(ISessionContext sessionContext, Deque<String> recentLocations) {
        this.sessionContext = sessionContext;
        this.recentLocations = recentLocations;
    }

}
